---
title: DeepResearchAgent
sidebarTitle: DeepResearchAgent
---

![DeepResearchAgent workflow](/snippets/reference-agents/img/DeepResearchAgent.png)

import DeepResearch from "/snippets/reference-agents/deep-research.mdx";

<DeepResearch/>
